<a class="widget-btn config-btn btn btn-default" ng:click="configureWidget(widget)" ng:show="widgetTypes[widget.typeId].config_template && customization.plugins.dashboard.allowConfigure" title="{{'Configure'|translate}}">
    <i class="fa fa-fw fa-wrench"></i>
</a>
<a class="widget-btn move-btn btn btn-default" sv:handle ng:show="customization.plugins.dashboard.allowMove">
    <i class="fa fa-fw fa-arrows"></i>
</a>
<a class="widget-btn remove-btn btn btn-default" ng:click="removeWidget(widget)" title="{{'Remove'|translate}}" ng:show="customization.plugins.dashboard.allowRemove">
    <i class="fa fa-fw fa-trash-o"></i>
</a>
<ng:include src="widgetTypes[widget.typeId].template" />
