<div ng:controller="LoadAverageWidgetController" class="row">
    <div class="col-xs-4">
        <div class="widget-header" translate>
            1 min
        </div>
        <div class="widget-value">
            {{load[0]}}
        </div>
    </div>
    <div class="col-xs-4">
        <div class="widget-header" translate>
            5 min
        </div>
        <div class="widget-value">
            {{load[1]}}
        </div>
    </div>
    <div class="col-xs-4">
        <div class="widget-header" translate>
            15 min
        </div>
        <div class="widget-value">
            {{load[2]}}
        </div>
    </div>
</div>
