{"": "", "15 min": "15 dk", "Uptime": "\u00c7al\u0131\u015fma s\u00fcresi", "Total": "Toplam", "Configure": "Yap\u0131land\u0131r", "Memory usage": "Bellek kullan\u0131m\u0131", "Hostname": "Ana makine ad\u0131", "Active cores": "Aktif \u00e7ekirdekler", "Add widget": "Widget ekle", "1 min": "1 dk", "Remove": "Kald\u0131r", "5 min": "5 dk", "CPU usage": "\u0130\u015flemci kullan\u0131m\u0131", "Save": "Kaydet", "Load average": "Ortalama Y\u00fck", "Dashboard": "Pano"}