{"": "", "15 min": "15 Min", "Uptime": "Laufzeit", "Total": "Gesamt", "Configure": "Konfigurieren", "Memory usage": "Speicherauslastung", "Hostname": "Hostname", "Active cores": "Aktive Kerne", "Add widget": "Widget hinzuf\u00fcgen", "1 min": "1\u00a0Min", "Remove": "Entfernen", "5 min": "5 Min", "CPU usage": "CPU-Auslastung", "Save": "Speichern", "Load average": "Durchschnittsbelastung", "Dashboard": "Dashboard"}