{"": "", "15 min": "15 min", "Uptime": "Uptime", "Total": "Razem", "Configure": "Konfiguruj", "Memory usage": "U\u017cycie pami\u0119ci", "Hostname": "Nazwa hosta", "Active cores": "Aktywnych rdzeni", "Add widget": "Dodaj widget", "1 min": "1 min", "Remove": "Usu\u0144", "5 min": "5 min", "CPU usage": "U\u017cycie procesora", "Save": "Zapisz", "Load average": "\u015arednie obci\u0105\u017cenie", "Dashboard": "Pulpit nawigacyjny"}