{"": "", "15 min": "15 perc", "Uptime": "\u00dczemid\u0151", "Total": "Teljes", "Configure": "Be\u00e1ll\u00edt\u00e1sok", "Memory usage": "Mem\u00f3ria haszn\u00e1lat", "Hostname": "Hosztn\u00e9v", "Active cores": "Akt\u00edv magok", "Add widget": "\u00daj widget", "1 min": "1 perc", "Remove": "T\u00f6rl\u00e9s", "5 min": "5 perc", "CPU usage": "CPU haszn\u00e1lat", "Save": "Ment\u00e9s", "Load average": "\u00c1tlagos terhel\u00e9s", "Dashboard": "Vez\u00e9rl\u0151pult"}