{"": "", "15 min": "15 min", "Uptime": "Tempo di funzionamento", "Total": "Totale", "Configure": "Configura", "Memory usage": "Memoria utilizzata", "Hostname": "Hostname", "Active cores": "Core attivi", "Add widget": "Aggiungi widget", "1 min": "1 min", "Remove": "Rimuovi", "5 min": "5 min", "CPU usage": "Utilizzo della CPU", "Save": "Salva", "Load average": "Utilizzo medio", "Dashboard": "Dashboard"}