{"": "", "15 min": "15 min", "Uptime": "Uptime", "Total": "Totaal", "Configure": "Configureren", "Memory usage": "Geheugen gebruik", "Hostname": "Hostnaam", "Active cores": "Actieve cores", "Add widget": "Widget toevoegen", "1 min": "1 min", "Remove": "Verwijderen", "5 min": "5 min", "CPU usage": "CPU-gebruik", "Save": "Opslaan", "Load average": "Gemiddelde belasting", "Dashboard": "Dashboard"}