{"": "", "15 min": "15\ubd84", "Uptime": "\uac00\ub3d9 \uc2dc\uac04", "Total": "\ucd1d\ud569", "Configure": "\uc124\uc815", "Memory usage": "\uba54\ubaa8\ub9ac \uc0ac\uc6a9\ub7c9", "Hostname": "\ud638\uc2a4\ud2b8 \uc774\ub984", "Active cores": "\ud65c\uc131\ub41c \ucf54\uc5b4", "Add widget": "\uc704\uc82f \ucd94\uac00", "1 min": "1\ubd84", "Remove": "\uc0ad\uc81c", "5 min": "5\ubd84", "CPU usage": "CPU \uc0ac\uc6a9\ub7c9", "Save": "\uc800\uc7a5", "Load average": "\ud3c9\uade0 \ubd80\ud558\ub7c9", "Dashboard": "\ub300\uc2dc\ubcf4\ub4dc"}