{"": "", "15 min": "15 min", "Uptime": "Uptime", "Total": "Total", "Configure": "Configurar", "Memory usage": "Uso de memoria", "Hostname": "Nombre del Host", "Active cores": "N\u00facleos activos", "Add widget": "A\u00f1adir widget", "1 min": "1 min", "Remove": "Eliminar", "5 min": "5 minutos", "CPU usage": "Uso de CPU", "Save": "Guardar", "Load average": "Promedio de carga", "Dashboard": "Panel de control"}