{"": "", "15 min": "15 min", "Uptime": "\u010cas delovanja", "Total": "Skupaj", "Configure": "Konfiguriraj", "Memory usage": "Poraba pomnilnika", "Hostname": "Ime gostitelja", "Active cores": "Aktivna jedra", "Add widget": "Dodaj gradnik", "1 min": "1 min", "Remove": "Odstrani", "5 min": "5 min", "CPU usage": "Poraba CPU", "Save": "Shrani", "Load average": "Povpre\u010dna obremenitev", "Dashboard": "Nadzorna plo\u0161\u010da"}