{"": "", "15 min": "15 min", "Uptime": "Temps de fonctionnement", "Total": "Total", "Configure": "Configurer", "Memory usage": "Utilisation m\u00e9moire", "Hostname": "Nom d'h\u00f4te", "Active cores": "Coeurs actifs", "Add widget": "Ajouter un widget", "1 min": "1 min", "Remove": "Supprimer", "5 min": "5 min", "CPU usage": "Utilisation CPU", "Save": "Enregistrer", "Load average": "Utilisation moyenne", "Dashboard": "Tableau de bord"}