{"": "", "15 min": "15 minut", "Uptime": "Doba provozu", "Total": "Celkem", "Configure": "Nastavit", "Memory usage": "Vyu\u017eit\u00ed pam\u011bti", "Hostname": "Hostname", "Active cores": "Aktivn\u00ed j\u00e1dra", "Add widget": "P\u0159idat widget", "1 min": "1 minuta", "Remove": "Odstranit", "5 min": "5 minut", "CPU usage": "Vyu\u017eit\u00ed procesoru", "Save": "Ulo\u017eit", "Load average": "Pr\u016fm\u011brn\u00e9 zat\u00ed\u017een\u00ed", "Dashboard": "N\u00e1st\u011bnka"}